package com.valtech.bootcamp.carRental.web.reservation;

import test.valtech.bootcamp.carRental.web.reservation.ReservationJBTest;
import com.valtech.bootcamp.carRental.service.reservationAgent.*;
import com.valtech.bootcamp.carRental.business.reservation.ReservationStateHolder;
import javax.naming.*;
import javax.rmi.*;

/**
 * Client side java bean for the Reservation object.<br><br>
 * @author Valtech UK
 * @version 1.0
 */
public class ReservationJB {


/**
 * the car type of the reservation
 */
private String carType = "";

/**
 * the name of the customer
 */
private String customerName = "";

/**
 * the end date of the reservation
 */
private String endDate = "";

/*
 * the reservation number of the reservation
 */
private String reservationNumber = "";

/**
 * the start date of the reservation
 */
private String startDate = "";





/**
 * @param reservationNumber the unique reservation number of the reservation.
 * @param startDate the start date of the reservation
 * @param endDate the end date of the reservation
 * @param carType the type of car specified in the reservation.
 * @param customerName the name of the customer making the reservation
 */
public ReservationJB(String reservationNumber, String startDate, String endDate, String carType, String customerName)
{
        this.carType = carType;
        this.customerName = customerName;
        this.endDate = endDate;
        this.startDate = startDate;

        /*
         * note the reservation number is set to a default here as the value gets reset.
         */
		this.reservationNumber = "555";
}

/**
 * populates the state holder attributes into the bean
 * @param rsh the state holder containing details of the reservation
 */
public ReservationJB(ReservationStateHolder rsh)
{
        this.carType = rsh.getCarType();
        this.customerName = rsh.getCustomerName();
        this.endDate = rsh.getEndDate();
        this.startDate = rsh.getStartDate();
        this.reservationNumber = rsh.getReservationNumber();
}

/**
  * overridden for the JUnit testing framework
  * @param rjb the ReservationJB that is being used in the comparison to the calling object
  */
public boolean equals( ReservationJB rjb)
{
    return (rjb.startDate.equals(this.startDate) && rjb.endDate.equals(this.endDate) && rjb.carType.equals(this.carType) && rjb.customerName.equals(this.customerName));
}

/**
* Default constructor
**/
public ReservationJB(){}


/**
 * gets the car type
 */
public String getCarType(){ return carType; }

/**
 * sets the car type
 */
public void setCarType(String carType){ this.carType = carType; }

/**
 * gets the customer name
 */
public String getCustomerName(){ return customerName; }


/**
 * sets the customer name
 */
public void setCustomerName(String customerName){ this.customerName = customerName; }


/**
 * gets the end date
 */
public String getEndDate(){ return endDate; }


/**
 * sets the end date
 */
public void setEndDate(String endDate){ this.endDate = endDate; }


/**
 * gets the reservation number
 */
public String getReservationNumber(){ return reservationNumber; }


/**
 * sets the reservation number
 */
public void setReservationNumber(String reservationNumber){ this.reservationNumber = reservationNumber; }


/**
 * gets the start date
 */
public String getStartDate(){ return startDate; }


/**
 * sets the start date
 */
public void setStartDate(String startDate){ this.startDate = startDate; }


/**
 * calls setReservation() on the ReservationAgent facade.
 */
public void setReservation()
{
        System.setProperty("java.naming.factory.initial",
            "org.jnp.interfaces.NamingContextFactory");
    	System.setProperty("java.naming.provider.url",
      		"localhost:1099");
       try
        {
        	Context initial = new InitialContext();
        	ReservationAgentHome resAgentHome = (ReservationAgentHome)PortableRemoteObject.narrow(initial.lookup("ReservationAgentBean"), ReservationAgentHome.class);
            ReservationAgent reservationAgent = resAgentHome.create();
        	String resCreate = reservationAgent.setReservation(getReservationStateHolder());
            System.out.println(resCreate);
            setReservationNumber(resCreate);
        }
        catch(Exception e)
        {
            System.out.print("Test Error");
            e.printStackTrace();
        }

}

/**
 * returns a state holder of the reservation.
 */
public ReservationStateHolder getReservation()
{
        ReservationStateHolder rsh = null;
        System.setProperty("java.naming.factory.initial",
            "org.jnp.interfaces.NamingContextFactory");
    	System.setProperty("java.naming.provider.url",
      		"localhost:1099");
       try
        {
        	Context initial = new InitialContext();
        	ReservationAgentHome resAgentHome = (ReservationAgentHome)PortableRemoteObject.narrow(initial.lookup("ReservationAgentBean"), ReservationAgentHome.class);
            ReservationAgent reservationAgent = resAgentHome.create();
        	rsh = reservationAgent.getReservation(this.reservationNumber);
        }
        catch(Exception e)
        {
            System.out.print("Test Error");
            e.printStackTrace();
        }
        return rsh;
}

/**
 * returns a state holder constructed from the bean attributes
 */
public ReservationStateHolder getReservationStateHolder()
{
    return new  ReservationStateHolder(this.reservationNumber, this.startDate, this.endDate, this.carType, this.customerName);
}

public void getRegistration()
{
}

/**
 * generates an XML document for the reservation entry form.
 */
public String toXML()
{
    return new String( "<?xml version=\"1.0\"?>" +
            	"<?cocoon-process type=\"xslt\"?>" +
            	"<?xml-stylesheet href=\"/stylesheet/form-html.xsl\" type=\"text/xsl\"?>"  +
                "<?xml-stylesheet href=\"/stylesheet/form-wml.xsl\" type=\"text/xsl\" media=\"wap\"?>"  +
					    "<form action=\"reserve.jsp\">" +
						"<head>" +
						"<title>ABC Car Rental</title>" +
						"</head>" +
						"<input type=\"text\" name=\"customerName\" value=\"" + this.getCustomerName() + "\" size=\"11\"/>" +
						"<input type=\"text\" name=\"carType\" value=\"" + this.getCarType() + "\" size=\"11\"/>" +
						"<input type=\"text\" name=\"startDate\" value=\"" + this.getStartDate() + "\" size=\"11\"/>" +
                        "<input type=\"text\" name=\"endDate\" value=\"" + this.getEndDate() + "\" size=\"11\"/>" +
                         "<input type=\"text\" name=\"reservationNo\" value=\"" + this.getReservationNumber() + "\" size=\"11\"/>" +
						"</form>" );
}


}
